==> haskell-shakespeare-2.0.15-24-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-shakespeare.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: shakespeare
version: 2.0.15
id: shakespeare-2.0.15-HmCfNxpPaFf1SGjZwPwgv0
key: shakespeare-2.0.15-HmCfNxpPaFf1SGjZwPwgv0
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/shakespearean-templates
synopsis: A toolkit for making compile-time interpolated templates
description:
    Shakespeare is a family of type-safe, efficient template languages. Shakespeare templates are expanded at compile-time, ensuring that all interpolated variables are in scope. Variables are interpolated according to their type through a typeclass.
    .
    Shakespeare templates can be used inline with a quasi-quoter or in an external file.
    .
    Note there is no dependency on haskell-src-extras. Instead Shakespeare believes logic should stay out of templates and has its own minimal Haskell parser.
    .
    Packages that use this: xml-hamlet
    .
    Please see the documentation at <http://www.yesodweb.com/book/shakespearean-templates> for more details.
category: Web, Yesod
abi: df08d434436ab0ef303bf816ba663fcc
exposed: True
exposed-modules:
    Text.Cassius Text.Coffee Text.Hamlet Text.Hamlet.RT
    Text.Hamlet.Runtime Text.Internal.Css Text.Internal.CssCommon
    Text.Julius Text.Lucius Text.Roy Text.Shakespeare
    Text.Shakespeare.Base Text.Shakespeare.I18N Text.Shakespeare.Text
    Text.TypeScript
hidden-modules: Text.Hamlet.Parse Text.MkSizeType
                Text.IndentToBrace
import-dirs: /usr/lib/ghc-8.4.2/site-local/shakespeare-2.0.15
library-dirs: /usr/lib/ghc-8.4.2/site-local/shakespeare-2.0.15
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/shakespeare-2.0.15
hs-libraries: HSshakespeare-2.0.15-HmCfNxpPaFf1SGjZwPwgv0
depends:
    base-4.11.1.0 time-1.8.0.2 containers-0.5.11.0
    template-haskell-2.13.0.0 parsec-3.1.13.0 text-1.2.3.0
    process-1.6.3.0 ghc-prim-0.5.2.0 bytestring-0.10.8.2
    directory-1.3.1.5 aeson-1.3.1.1-Jc2ftlprW3RD5JNULfJPh2
    blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug
    blaze-html-0.9.0.1-GE6MVgSdj1NIDsAcI8SbsY
    exceptions-0.8.3-Ii5Q7YFckHgBserQRiDSiR transformers-0.5.5.0
    vector-0.12.0.1-4awQG9XUvVEBfJgKGHBhOb
    unordered-containers-0.2.9.0-KdZ4KMfcSgfH94a9qKVvIF
    scientific-0.3.6.2-5CyHdegMsTFBY4p5C2C7g8
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             time-1.8.0.2=f5b6d28c2b89a17d60f5dfeda767abd0
             containers-0.5.11.0=f8334bacfaf0e925ca7b24fb26fb2e66
             template-haskell-2.13.0.0=b25d144eee230069f091d0d8982b331b
             parsec-3.1.13.0=b976f306e11b572c7d5898bcff511199
             text-1.2.3.0=5654b56910ce698015ec900075c28f62
             process-1.6.3.0=f742183dfb18804fd4a4a0e3c09be01d
             ghc-prim-0.5.2.0=a22477c99003a90dd639dbfd07997615
             bytestring-0.10.8.2=c1695cedf0cebf0c12d34c90fb94a65f
             directory-1.3.1.5=c4ddb2059d4b7fed7d39b1d1bb3bf41d
             aeson-1.3.1.1-Jc2ftlprW3RD5JNULfJPh2=d6221140607342466670e5a4aa799750
             blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug=def93a85bb7baaa629d1f7cd155b869c
             blaze-html-0.9.0.1-GE6MVgSdj1NIDsAcI8SbsY=962e8d2161f35068fcc031ff6a6bdfd0
             exceptions-0.8.3-Ii5Q7YFckHgBserQRiDSiR=9f60f161536a7d4278dffe801494d805
             transformers-0.5.5.0=02be5c4dc3fdc926cf1b36bd484a25f8
             vector-0.12.0.1-4awQG9XUvVEBfJgKGHBhOb=6eab66b6328cb1f1f60a88d42282d4d0
             unordered-containers-0.2.9.0-KdZ4KMfcSgfH94a9qKVvIF=2ade52955b9fa0964135ae12d3c6ee25
             scientific-0.3.6.2-5CyHdegMsTFBY4p5C2C7g8=bf2c4ab253b66175121fc647b8699c7c
haddock-interfaces: /usr/share/doc/haskell-shakespeare/html/shakespeare.haddock
haddock-html: /usr/share/doc/haskell-shakespeare/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-shakespeare-2.0.15-29-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-shakespeare.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: shakespeare
version: 2.0.15
id: shakespeare-2.0.15-DcnJ69f99nyFLEi5a0pQx1
key: shakespeare-2.0.15-DcnJ69f99nyFLEi5a0pQx1
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/shakespearean-templates
synopsis: A toolkit for making compile-time interpolated templates
description:
    Shakespeare is a family of type-safe, efficient template languages. Shakespeare templates are expanded at compile-time, ensuring that all interpolated variables are in scope. Variables are interpolated according to their type through a typeclass.
    .
    Shakespeare templates can be used inline with a quasi-quoter or in an external file.
    .
    Note there is no dependency on haskell-src-extras. Instead Shakespeare believes logic should stay out of templates and has its own minimal Haskell parser.
    .
    Packages that use this: xml-hamlet
    .
    Please see the documentation at <http://www.yesodweb.com/book/shakespearean-templates> for more details.
category: Web, Yesod
abi: 192933bb200d0f791a9a9c3049be476d
exposed: True
exposed-modules:
    Text.Cassius Text.Coffee Text.Hamlet Text.Hamlet.RT
    Text.Hamlet.Runtime Text.Internal.Css Text.Internal.CssCommon
    Text.Julius Text.Lucius Text.Roy Text.Shakespeare
    Text.Shakespeare.Base Text.Shakespeare.I18N Text.Shakespeare.Text
    Text.TypeScript
hidden-modules: Text.Hamlet.Parse Text.MkSizeType
                Text.IndentToBrace
import-dirs: /usr/lib/ghc-8.4.2/site-local/shakespeare-2.0.15
library-dirs: /usr/lib/ghc-8.4.2/site-local/shakespeare-2.0.15
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/shakespeare-2.0.15
hs-libraries: HSshakespeare-2.0.15-DcnJ69f99nyFLEi5a0pQx1
depends:
    base-4.11.1.0 time-1.8.0.2 containers-0.5.11.0
    template-haskell-2.13.0.0 parsec-3.1.13.0 text-1.2.3.0
    process-1.6.3.0 ghc-prim-0.5.2.0 bytestring-0.10.8.2
    directory-1.3.1.5 aeson-1.3.1.1-dcIxm637We4CZtEjnOqrp
    blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug
    blaze-html-0.9.0.1-GE6MVgSdj1NIDsAcI8SbsY
    exceptions-0.8.3-6WkrztLwxRv2NB3qEvHVbf transformers-0.5.5.0
    vector-0.12.0.1-4awQG9XUvVEBfJgKGHBhOb
    unordered-containers-0.2.9.0-A3KBTFupd4vFLOQxsI6884
    scientific-0.3.6.2-5CyHdegMsTFBY4p5C2C7g8
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             time-1.8.0.2=f5b6d28c2b89a17d60f5dfeda767abd0
             containers-0.5.11.0=f8334bacfaf0e925ca7b24fb26fb2e66
             template-haskell-2.13.0.0=b25d144eee230069f091d0d8982b331b
             parsec-3.1.13.0=b976f306e11b572c7d5898bcff511199
             text-1.2.3.0=5654b56910ce698015ec900075c28f62
             process-1.6.3.0=f742183dfb18804fd4a4a0e3c09be01d
             ghc-prim-0.5.2.0=a22477c99003a90dd639dbfd07997615
             bytestring-0.10.8.2=c1695cedf0cebf0c12d34c90fb94a65f
             directory-1.3.1.5=c4ddb2059d4b7fed7d39b1d1bb3bf41d
             aeson-1.3.1.1-dcIxm637We4CZtEjnOqrp=6f34fa436c981af2b0589cc66168565f
             blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug=def93a85bb7baaa629d1f7cd155b869c
             blaze-html-0.9.0.1-GE6MVgSdj1NIDsAcI8SbsY=962e8d2161f35068fcc031ff6a6bdfd0
             exceptions-0.8.3-6WkrztLwxRv2NB3qEvHVbf=90dd74da021381146ba64944278df775
             transformers-0.5.5.0=02be5c4dc3fdc926cf1b36bd484a25f8
             vector-0.12.0.1-4awQG9XUvVEBfJgKGHBhOb=6eab66b6328cb1f1f60a88d42282d4d0
             unordered-containers-0.2.9.0-A3KBTFupd4vFLOQxsI6884=c76b79dc8a56ff4425c082d0052b04f4
             scientific-0.3.6.2-5CyHdegMsTFBY4p5C2C7g8=bf2c4ab253b66175121fc647b8699c7c
haddock-interfaces: /usr/share/doc/haskell-shakespeare/html/shakespeare.haddock
haddock-html: /usr/share/doc/haskell-shakespeare/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
